==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "1. korak je spodletel. Izjemna napaka: %s",
    "Step 2 failed. Exception: %s" : "2. korak je spodletel. Izjemna napaka: %s",
    "External storage" : "Zunanja shramba",
    "Storage with id \"%i\" not found" : "Shrambe z ID \"%i\" ni mogoče najti.",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe \"%s\"",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "Grant access" : "Odobri dostop",
    "Access granted" : "Dostop je odobren",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predogled",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
    "(group)" : "(skupina)",
    "Saved" : "Shranjeno",
    "External mount error" : "Notranja napaka priklopa",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Save" : "Shrani",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skriti ključ",
    "Builtin" : "Vgrajeno",
    "None" : "Brez",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Ime uporabnika",
    "API key" : "Ključ API",
    "Username and password" : "Uporabniško ime in geslo",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Pomnilniško vedro",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Gostitelj",
    "Secure ftps://" : "Varni način ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava prek protokola SFTP z geslom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Domain" : "Domena",
    "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "Username as share" : "Uporabniško ime za souporabo",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "<b>Note:</b> " : "<b>Opomba:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za naslove cURL v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za protokol FTP v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Program \"%s\" ni nameščen. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "No external storage configured" : "Ni določene zunanje shrambe",
    "You can add external storages in the personal settings" : "Med nastavitvami je mogoče dodati tudi zunanjo shrambo.",
    "Name" : "Ime",
    "Storage type" : "Vrsta shrambe",
    "Scope" : "Obseg",
    "External Storage" : "Zunanja podatkovna shramba",
    "Folder name" : "Ime mape",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Delete" : "Izbriši",
    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe",
    "Allow users to mount the following external storage" : "Dovoli uporabnikom priklapljanje navedenih zunanjih shramb.",
    "Admin defined" : "Skrbnik je določen",
    "Credentials required" : "Zahtevana so poverila",
    "Credentials saved" : "Poverila so shranjena",
    "Credentials saving failed" : "Shranjevanje poveril je spodletelo",
    "Enable sharing" : "Omogoči souporabo",
    "external-storage" : "zunanja-shramba",
    "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
    "Please enter the credentials for the {mount} mount" : "Vpišite poverila za priklopno točko {mount}",
    "SMB / CIFS" : "SMB / CIFS",
    "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
    "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Pridobivanje žetonov zahteve je spodletelo. Preverite, ali sta ključ in skrivno geslo programa navedena pravilno.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Pridobivanje žetonov za dostop je spodletelo. Preverite, da sta ključ in skrivno geslo navedena pravilno.",
    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo.",
    "Step 1 failed. Exception: %s" : "1. korak je spodletel. Izjemna napaka: %s",
    "Step 2 failed. Exception: %s" : "2. korak je spodletel. Izjemna napaka: %s",
    "External storage" : "Zunanja shramba",
    "Dropbox App Configuration" : "Nastavitve programa Dropbox",
    "Google Drive App Configuration" : "Nastavitve programa Google Drive",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "Grant access" : "Odobri dostop",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
    "(group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : "Usklajenost z Mac NFD šifriranjem (počasno)",
    "Admin defined" : "Skrbnik je določen",
    "Saved" : "Shranjeno",
    "Empty response from the server" : "S strežnika je prejet odziv brez vsebine.",
    "Couldn't access. Please logout and login to activate this mount point" : "Dostop ni mogoč. Za priklop točke se odjavite in ponovno prijavite.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Ni mogoče pridobiti podrobnosti s strežnika ownCloud:{koda} {vrsta}",
    "Couldn't get the list of external mount points: {type}" : "Ni mogoče pridobiti seznama zunanjih priklopnih točk: {type}",
    "There was an error with message: " : "Prišlo je do napake s sporočilom:",
    "External mount error" : "Notranja napaka priklopa",
    "external-storage" : "zunanja-shramba",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Ni mogoče pridobiti seznama priklopnih točk omrežnega pogona: ni odziva s strežnika",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Nekatere izmed nastavljenih zunanjih priklopnih točk niso povezane. Več podrobnosti je na voljo s klikom na rdeče vrstice.",
    "Please enter the credentials for the {mount} mount" : "Vpišite poverila za priklopno točko {mount}",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Credentials saved" : "Poverila so shranjena",
    "Credentials saving failed" : "Shranjevanje poveril je spodletelo",
    "Credentials required" : "Zahtevana so poverila",
    "Save" : "Shrani",
    "Storage with id \"%i\" not found" : "Shrambe z ID \"%i\" ni mogoče najti.",
    "Invalid backend or authentication mechanism class" : "Neveljaven ozadnji program oziroma razred mehanizma overitve",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Objectstore forbidden" : "Shranjevanje predmeta je prepovedano",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe \"%s\"",
    "Not permitted to use backend \"%s\"" : "Uporaba ozadnjega programa \"%s\" ni dovoljena.",
    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve \"%s\" ni dovoljena.",
    "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa",
    "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Shramba z ID \"%i\" ni uporabniško uredljiva.",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skriti ključ",
    "Builtin" : "Vgrajeno",
    "None" : "Brez",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Ime uporabnika",
    "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API",
    "Username and password" : "Uporabniško ime in geslo",
    "Log-in credentials, save in session" : "Prijavna poverila, shrani v seji",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Pomnilniško vedro",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Gostitelj",
    "Secure ftps://" : "Varni način ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava prek protokola SFTP z geslom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Domain" : "Domena",
    "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "Username as share" : "Uporabniško ime za souporabo",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "Request timeout (seconds)" : "Zahtevan časovni zamik (sekunde)",
    "<b>Note:</b> " : "<b>Opomba:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za naslove cURL v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za protokol FTP v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Program \"%s\" ni nameščen. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "No external storage configured" : "Ni določene zunanje shrambe",
    "You can add external storages in the personal settings" : "Med nastavitvami je mogoče dodati tudi zunanjo shrambo.",
    "Name" : "Ime",
    "Storage type" : "Vrsta shrambe",
    "Scope" : "Obseg",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predogled",
    "Enable sharing" : "Omogoči souporabo",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "External Storage" : "Zunanja podatkovna shramba",
    "Folder name" : "Ime mape",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Delete" : "Izbriši",
    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe",
    "Allow users to mount the following external storage" : "Dovoli uporabnikom priklapljanje navedenih zunanjih shramb."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
